@@ -1,22 +1,10 @@
-/***************************************************************************
- *   Copyright  2010 Johannes Loehnert <loehnert.kde@gmx.net>
- * based on the Jigsaw slicer (c) 2009 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Johannes Loehnert <loehnert.kde@gmx.net>
+    Based on the Jigsaw slicer by:
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "slicer-goldberg.h"
 
@@ -27,7 +15,7 @@
 #include "grid.h"
 #include "utilities.h"
 
-K_PLUGIN_FACTORY(SvgSlicerFactory, registerPlugin<GoldbergSlicer>();)
+K_PLUGIN_CLASS_WITH_JSON(GoldbergSlicer, "palapeli_goldbergslicer.json")
 
 GoldbergSlicer::GoldbergSlicer(QObject* parent, const QVariantList& args)
             : Pala::Slicer(parent, args) {
@@ -38,13 +26,13 @@ GoldbergSlicer::GoldbergSlicer(QObject* parent, const QVariantList& args)
 
     m_qvoronoi_available = IrregularMode::checkForQVoronoi();
 
-    Pala::SlicerMode* presetMode = 0;
+    Pala::SlicerMode* presetMode = nullptr;
     addMode(presetMode = new PresetMode);
     addMode(new RectMode);
     addMode(new CairoMode);
     addMode(new HexMode);
     addMode(new RotrexMode);
-    Pala::SlicerMode* irregularMode = 0;
+    Pala::SlicerMode* irregularMode = nullptr;
     if (m_qvoronoi_available)
         addMode(irregularMode = new IrregularMode);
 
