@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *   Copyright 2010 Johannes Löhnert <loehnert.kde@gmx.de>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+    SPDX-FileCopyrightText: 2010 Johannes Löhnert <loehnert.kde@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mergegroup.h"
 #include "piece.h"
@@ -48,10 +36,14 @@ QList<Palapeli::Piece*> Palapeli::MergeGroup::tryGrowMergeGroup(Palapeli::Piece*
 	{
 		addedSomethingInThisLoop = false; //not yet
 		//check all neighbors of the currently included pieces
-		foreach (Palapeli::Piece* piece, resultList)
+		const auto currentResultList = resultList;
+		for (Palapeli::Piece* piece : currentResultList)
 		{
-			foreach (Palapeli::Piece* logicalNeighbor, piece->logicalNeighbors())
+			const auto logicalNeighbors = piece->logicalNeighbors();
+			for (Palapeli::Piece* logicalNeighbor : logicalNeighbors)
 			{
+				if (piece->scene() != logicalNeighbor->scene())
+					continue;
 				//no need to check the located physical neighbors again
 				if (resultSet.contains(logicalNeighbor))
 					continue;
@@ -71,13 +63,13 @@ QList<Palapeli::Piece*> Palapeli::MergeGroup::tryGrowMergeGroup(Palapeli::Piece*
 Palapeli::MergeGroup::MergeGroup(const QList<Palapeli::Piece*>& pieces, QGraphicsScene* scene, const QSizeF& pieceAreaSize, bool animated)
 	: m_animated(animated)
 	, m_pieces(pieces)
-	, m_mergedPiece(0)
+	, m_mergedPiece(nullptr)
 	, m_scene(scene)
 	, m_pieceAreaSize(pieceAreaSize)
 {
 	//find united coordinate system (UCS) -> large pieces contribute more than smaller pieces
 	int totalWeight = 0;
-	foreach (Palapeli::Piece* piece, pieces)
+	for (Palapeli::Piece* piece : pieces)
 	{
 		const int weight = piece->representedAtomicPieces().count();
 		m_ucsPosition += weight * piece->pos();
@@ -95,9 +87,9 @@ void Palapeli::MergeGroup::start()
 	{
 		//create animations for merging the piece coordinate systems into the UCS
 		QParallelAnimationGroup* masterAnimator = new QParallelAnimationGroup(this);
-		foreach (Palapeli::Piece* piece, m_pieces)
+		for (Palapeli::Piece* piece : qAsConst(m_pieces))
 		{
-			QPropertyAnimation* pieceAnimator = new QPropertyAnimation(piece, "pos", 0);
+			QPropertyAnimation* pieceAnimator = new QPropertyAnimation(piece, "pos", nullptr);
 			pieceAnimator->setStartValue(piece->pos());
 			pieceAnimator->setEndValue(m_ucsPosition);
 			pieceAnimator->setDuration(200);
@@ -121,7 +113,7 @@ void Palapeli::MergeGroup::createMergedPiece()
 	QList<Palapeli::PieceVisuals> shadowVisuals;
 	QList<Palapeli::PieceVisuals> highlightVisuals;
 	bool allPiecesHaveShadows = true;
-	foreach (Palapeli::Piece* piece, m_pieces)
+	for (Palapeli::Piece* piece : qAsConst(m_pieces))
 	{
 		pieceVisuals << piece->pieceVisuals();
 		if (allPiecesHaveShadows) //we stop collecting shadow samples when one piece has no shadow
@@ -155,7 +147,7 @@ void Palapeli::MergeGroup::createMergedPiece()
 	}
 	m_mergedPiece->setPos(m_ucsPosition);
 	//transfer information from old pieces to new piece, then destroy old pieces
-	foreach (Palapeli::Piece* piece, m_pieces)
+	for (Palapeli::Piece* piece : qAsConst(m_pieces))
 	{
 		m_mergedPiece->addRepresentedAtomicPieces(piece->representedAtomicPieces());
 		m_mergedPiece->addLogicalNeighbors(piece->logicalNeighbors());
@@ -165,11 +157,12 @@ void Palapeli::MergeGroup::createMergedPiece()
 		m_mergedPiece->setZValue(qMax(m_mergedPiece->zValue(), piece->zValue()));
 		piece->announceReplaced(m_mergedPiece); //make sure that interactors know about the change, and delete the piece
 	}
-	m_mergedPiece->rewriteLogicalNeighbors(m_pieces, 0); //0 = these neighbors should be dropped
-	foreach (Palapeli::Piece* logicalNeighbor, m_mergedPiece->logicalNeighbors())
+	m_mergedPiece->rewriteLogicalNeighbors(m_pieces, nullptr); //0 = these neighbors should be dropped
+	const auto logicalNeighbors = m_mergedPiece->logicalNeighbors();
+	for (Palapeli::Piece* logicalNeighbor : logicalNeighbors)
 		logicalNeighbor->rewriteLogicalNeighbors(m_pieces, m_mergedPiece); //these neighbors are now represented by m_mergedPiece
 	//transaction done
-	emit pieceInstanceTransaction(m_pieces, QList<Palapeli::Piece*>() << m_mergedPiece);
+	Q_EMIT pieceInstanceTransaction(m_pieces, QList<Palapeli::Piece*>() << m_mergedPiece);
 
 	// Do not highlight the merged piece, esp. not the solution-in-progress.
 	m_mergedPiece->setSelected(false);
