@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "scene.h"
 #include "constraintvisualizer.h"
@@ -29,7 +17,7 @@ Palapeli::Scene::Scene(QObject* parent)
 	: QGraphicsScene(parent)
 	, m_constrained(false)
 	, m_constraintVisualizer(new Palapeli::ConstraintVisualizer(this))
-	, m_puzzle(0)
+	, m_puzzle(nullptr)
 	, m_pieceAreaSize(QSizeF(32.0, 32.0))	// Allow 1024 pixels initially.
 	, m_margin(10.0)
 	, m_handleWidth(7.0)
@@ -45,7 +33,7 @@ void Palapeli::Scene::addPieceToList(Palapeli::Piece* piece)
 
 void Palapeli::Scene::addPieceItemsToScene()
 {
-	foreach (Palapeli::Piece * piece, m_pieces) {
+	for (Palapeli::Piece * piece : qAsConst(m_pieces)) {
 		addItem(piece);
 		connect(piece, &Piece::moved, this, &Scene::pieceMoved);
 	}
@@ -53,7 +41,7 @@ void Palapeli::Scene::addPieceItemsToScene()
 
 void Palapeli::Scene::dispatchPieces(const QList<Palapeli::Piece*> &pieces)
 {
-	foreach (Palapeli::Piece * piece, pieces) {
+	for (Palapeli::Piece * piece : pieces) {
 		piece->setSelected(false);
 		removeItem(piece);
 		m_pieces.removeAll(piece);
@@ -101,7 +89,7 @@ QRectF Palapeli::Scene::piecesBoundingRect() const
 	// If no pieces, space is >= m_minGrid*m_minGrid pieces (e.g. for a new
 	// PieceHolder). Default is >= 1 piece for the puzzle table.
 	QRectF result;
-	foreach (Palapeli::Piece* piece, m_pieces)
+	for (Palapeli::Piece* piece : m_pieces)
 		result |= piece->sceneBareBoundingRect();
 	QSizeF minSize = m_minGrid * m_gridSpacing;
 	QRectF minRect(QPointF(0.0, 0.0), minSize);
@@ -123,7 +111,7 @@ void Palapeli::Scene::setConstrained(bool constrained)
 		return;
 	m_constrained = constrained;
 	m_constraintVisualizer->setActive(constrained);
-	emit constrainedChanged(constrained);
+	Q_EMIT constrainedChanged(constrained);
 }
 
 void Palapeli::Scene::validatePiecePosition(Palapeli::Piece* piece)
@@ -174,7 +162,7 @@ void Palapeli::Scene::searchConnections(const QList<Palapeli::Piece*>& pieces,
 		Palapeli::Piece* piece = uncheckedPieces.takeFirst();
 		const QList<Palapeli::Piece*> pieceGroup =
 			Palapeli::MergeGroup::tryGrowMergeGroup(piece);
-		foreach (Palapeli::Piece* checkedPiece, pieceGroup)
+		for (Palapeli::Piece* checkedPiece : pieceGroup)
 			uncheckedPieces.removeAll(checkedPiece);
 		if (pieceGroup.size() > 1)
 		{
@@ -191,27 +179,27 @@ void Palapeli::Scene::pieceInstanceTransaction(const QList<Palapeli::Piece*>& de
 {
 	// qCDebug(PALAPELI_LOG) << "Scene::pieceInstanceTransaction(delete" << deletedPieces.count() << "add" << createdPieces.count();
 	const int oldPieceCount = m_pieces.count();
-	foreach (Palapeli::Piece* oldPiece, deletedPieces)
-		m_pieces.removeAll(oldPiece); //these pieces have been deleted by the caller
-	foreach (Palapeli::Piece* newPiece, createdPieces)
+	dispatchPieces(deletedPieces);
+	for (Palapeli::Piece* newPiece : createdPieces)
 	{
-		m_pieces << newPiece;
+		addPieceToList (newPiece);
 		connect(newPiece, &Piece::moved,
 			this, &Scene::pieceMoved);
 	}
 	// qCDebug(PALAPELI_LOG) << "emit saveMove(" << oldPieceCount - m_pieces.count();
-	emit saveMove(oldPieceCount - m_pieces.count());
+	Q_EMIT saveMove(oldPieceCount - m_pieces.count());
 }
 
 void Palapeli::Scene::pieceMoved(bool finished)
 {
 	if (!finished) {
-		emit saveMove(0);
+		Q_EMIT saveMove(0);
 		return;
 	}
 	// int before = m_pieces.count();
 	QList<Palapeli::Piece*> mergeCandidates;
-	foreach (QGraphicsItem* item, selectedItems())
+	const auto selectedItems = this->selectedItems();
+	for (QGraphicsItem* item : selectedItems)
 	{
 		Palapeli::Piece* piece = Palapeli::Piece::fromSelectedItem(item);
 		if (piece)
