@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "collection-view.h"
 #include "collection.h"
@@ -111,21 +99,21 @@ void Palapeli::CollectionView::handleActivated(const QModelIndex& index)
 		return;
 	//change selection to indicate that the given puzzle has been chosen
 	m_view->selectionModel()->select(index, QItemSelectionModel::ClearAndSelect);
-	emit playRequest(Palapeli::Collection::instance()->puzzleFromIndex(index));
+	Q_EMIT playRequest(Palapeli::Collection::instance()->puzzleFromIndex(index));
 }
 
 void Palapeli::CollectionView::handleSelectionChanged()
 {
 	const QModelIndexList indexes = m_view->selectionModel()->selectedIndexes();
 	const bool someSelection = !indexes.isEmpty();
-	emit canExportChanged(someSelection);
-	foreach (const QModelIndex& index, indexes)
+	Q_EMIT canExportChanged(someSelection);
+	for (const QModelIndex& index : indexes)
 		if (!index.data(Palapeli::Collection::IsDeleteableRole).toBool())
 		{
-			emit canDeleteChanged(false);
+			Q_EMIT canDeleteChanged(false);
 			return;
 		}
-	emit canDeleteChanged(someSelection);
+	Q_EMIT canDeleteChanged(someSelection);
 }
 
 void Palapeli::CollectionView::sortMenuTriggered(QAction* action)
